@@ -22,9 +22,8 @@ module RSpec::Core
       begin
         parser(options).parse!(args)
       rescue OptionParser::InvalidOption => e
-        failure = e.message
-        failure << " (defined in #{source})" if source
-        abort "#{failure}\n\nPlease use --help for a listing of valid options"
+        abort "#{e.message}#{" (defined in #{source})" if source}\n\n" \
+              "Please use --help for a listing of valid options"
       end
 
       options[:files_or_directories_to_run] = args
@@ -37,8 +36,11 @@ module RSpec::Core
     # rubocop:disable Metrics/AbcSize
     # rubocop:disable CyclomaticComplexity
     # rubocop:disable PerceivedComplexity
+    # rubocop:disable Metrics/BlockLength
     def parser(options)
       OptionParser.new do |parser|
+        parser.summary_width = 34
+
         parser.banner = "Usage: rspec [options] [files or directories]\n\n"
 
         parser.on('-I PATH', 'Specify PATH to add to $LOAD_PATH (may be used more than once).') do |dirs|
@@ -56,10 +58,11 @@ module RSpec::Core
         end
 
         parser.on('--order TYPE[:SEED]', 'Run examples by the specified order type.',
-                  '  [defined] examples and groups are run in the order they are defined',
-                  '  [rand]    randomize the order of groups and examples',
-                  '  [random]  alias for rand',
-                  '  [random:SEED] e.g. --order random:123') do |o|
+                  '  [defined]           examples and groups are run in the order they are defined',
+                  '  [rand]              randomize the order of groups and examples',
+                  '  [random]            alias for rand',
+                  '  [random:SEED]       e.g. --order random:123',
+                  '  [recently-modified] run the most recently modified files first') do |o|
           options[:order] = o
         end
 
@@ -93,9 +96,9 @@ module RSpec::Core
           options[:failure_exit_code] = code
         end
 
-        parser.on('--dry-run', 'Print the formatter output of your suite without',
-                  '  running any examples or hooks') do |_o|
-          options[:dry_run] = true
+        parser.on('--error-exit-code CODE', Integer,
+                  'Override the exit code used when there are errors loading or running specs outside of examples.') do |code|
+          options[:error_exit_code] = code
         end
 
         parser.on('-X', '--[no-]drb', 'Run examples via DRb.') do |use_drb|
@@ -107,10 +110,6 @@ module RSpec::Core
           options[:drb_port] = o.to_i
         end
 
-        parser.on('--init', 'Initialize your project with RSpec.') do |_cmd|
-          options[:runner] = RSpec::Core::Invocations::InitializeProject.new
-        end
-
         parser.separator("\n  **** Output ****\n\n")
 
         parser.on('-f', '--format FORMATTER', 'Choose a formatter.',
@@ -118,6 +117,7 @@ module RSpec::Core
                   '  [d]ocumentation (group and example names)',
                   '  [h]tml',
                   '  [j]son',
+                  '  [f]ailures ("file:line:reason", suitable for editors integration)',
                   '  custom formatter class name') do |o|
           options[:formatters] ||= []
           options[:formatters] << [o]
@@ -140,8 +140,24 @@ module RSpec::Core
           options[:full_backtrace] = true
         end
 
-        parser.on('-c', '--[no-]color', '--[no-]colour', 'Enable color in the output.') do |o|
-          options[:color] = o
+        parser.on('-c', '--color', '--colour', '') do |_o|
+          # flag will be excluded from `--help` output because it is deprecated
+          options[:color] = true
+          options[:color_mode] = :automatic
+        end
+
+        parser.on('--force-color', '--force-colour', 'Force the output to be in color, even if the output is not a TTY') do |_o|
+          if options[:color_mode] == :off
+            abort "Please only use one of `--force-color` and `--no-color`"
+          end
+          options[:color_mode] = :on
+        end
+
+        parser.on('--no-color', '--no-colour', 'Force the output to not be in color, even if the output is a TTY') do |_o|
+          if options[:color_mode] == :on
+            abort "Please only use one of --force-color and --no-color"
+          end
+          options[:color_mode] = :off
         end
 
         parser.on('-p', '--[no-]profile [COUNT]',
@@ -163,7 +179,15 @@ module RSpec::Core
                                        end
         end
 
+        parser.on('--dry-run', 'Print the formatter output of your suite without',
+                  '  running any examples or hooks') do |_o|
+          options[:dry_run] = true
+        end
+
         parser.on('-w', '--warnings', 'Enable ruby warnings') do
+          if Object.const_defined?(:Warning) && Warning.respond_to?(:[]=)
+            Warning[:deprecated] = true
+          end
           $VERBOSE = true
         end
 
@@ -187,7 +211,7 @@ FILTERING
           configure_only_failures(options)
         end
 
-        parser.on("--next-failure", "Apply `--only-failures` and abort after one failure.",
+        parser.on("-n", "--next-failure", "Apply `--only-failures` and abort after one failure.",
                   "  (Equivalent to `--only-failures --fail-fast --order defined`)") do
           configure_only_failures(options)
           set_fail_fast(options, 1)
@@ -212,6 +236,11 @@ FILTERING
           (options[:full_description] ||= []) << Regexp.compile(Regexp.escape(o))
         end
 
+        parser.on('-E', '--example-matches REGEX', "Run examples whose full nested names match REGEX (may be",
+                  "  used more than once)") do |o|
+          (options[:full_description] ||= []) << Regexp.compile(o)
+        end
+
         parser.on('-t', '--tag TAG[:VALUE]',
                   'Run examples with the specified tag, or exclude examples',
                   'by adding ~ before the tag.',
@@ -244,6 +273,10 @@ FILTERING
 
         parser.separator("\n  **** Utility ****\n\n")
 
+        parser.on('--init', 'Initialize your project with RSpec.') do |_cmd|
+          options[:runner] = RSpec::Core::Invocations::InitializeProject.new
+        end
+
         parser.on('-v', '--version', 'Display the version.') do
           options[:runner] = RSpec::Core::Invocations::PrintVersion.new
         end
@@ -256,8 +289,10 @@ FILTERING
         #     trigger --default-path.
         invalid_options = %w[-d --I]
 
+        hidden_options = invalid_options + %w[-c]
+
         parser.on_tail('-h', '--help', "You're looking at it.") do
-          options[:runner] = RSpec::Core::Invocations::PrintHelp.new(parser, invalid_options)
+          options[:runner] = RSpec::Core::Invocations::PrintHelp.new(parser, hidden_options)
         end
 
         # This prevents usage of the invalid_options.
@@ -268,6 +303,7 @@ FILTERING
         end
       end
     end
+    # rubocop:enable Metrics/BlockLength
     # rubocop:enable Metrics/AbcSize
     # rubocop:enable MethodLength
     # rubocop:enable CyclomaticComplexity
